pygeodesy.booleans._LatLonBool

Package pygeodesy :: Module booleans :: Class _LatLonBool |
[frames] | no frames]

# Class _LatLonBool

      object --+
               |
    named._Named --+
                   |
                  _LatLonBool

Known Subclasses:
  - LatLonFHP
  - , LatLonGH

(INTERNAL) Base class for LatLonFHP and LatLonGH.

Instance Methods
__init__(self, lat_ll, lon=None, height=0, clipid=0, wrap=False, **name) New `LatLon[FHP|GH]` from separate `lat`, `lon`, `height` and `clipid` scalars or from a previous `LatLon[FHP|GH]`, `Clip[FHP|GH]4Tuple` or some other `LatLon` instance. |
__abs__(self) |
__eq__(self, other) |
__ne__(self, other) |
__repr__(self) String `repr` of this lat-/longitude. |
__str__(self) String `str` of this lat-/longitude. |
__sub__(self, other) |
isequalTo(self, other, eps=None) Is this point equal to an `other` within a given, non-negative tolerance, ignoring `height`? |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| clipid Get the clipid (`int` or `0`).
| height Get the height (`Height` or `int`).
| isintersection Is this an intersection? May be `ispoint` too!
| ispoint Is this an original point? May be `isintersection` too!
| lat Get the latitude (`scalar`).
| latlon Get the lat- and longitude (LatLon2Tuple).
| lon Get the longitude (`scalar`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lat_ll, lon=None, height=0, clipid=0, wrap=False, **name) (Constructor) |
New `LatLon[FHP|GH]` from separate `lat`, `lon`, `height` and `clipid` scalars or from a previous `LatLon[FHP|GH]`, `Clip[FHP|GH]4Tuple` or some other `LatLon` instance. Arguments: `lat_ll` - Latitude (`scalar`) or a lat-/longitude (`LatLon[FHP|GH]`, `Clip[FHP|GH]4Tuple` or some other `LatLon`). `lon` - Longitude (`scalar`), required `lat_ll` is scalar, ignored otherwise. `height` - Height (`scalar`), conventionally `meter`. `clipid` - Clip identifier (`int`). `wrap` - If `True`, wrap or normalize `lat` and `lon` (`bool`). `name` - Optional `name=NN` (`str`). Overrides: object.__init__

### __repr__ (self) (Representation operator) |
String `repr` of this lat-/longitude. Overrides: object.__repr__

### __str__ (self) (Informal representation operator) |
String `str` of this lat-/longitude. Overrides: object.__str__

### isequalTo (self, other, eps=None) |
Is this point equal to an `other` within a given, non-negative tolerance, ignoring `height`? Arguments: `other` - The other point (`LatLon`). `eps` - Tolerance for equality (`degrees` or `None`). Returns: `True` if equivalent, `False` otherwise (`bool`). Raises: `TypeError` - Invalid `other`.

Property Details

### clipid Get the clipid (`int` or `0`). Get method: clipid(self) - Get the clipid (`int` or `0`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### height Get the height (`Height` or `int`). Get method: height(self) - Get the height (`Height` or `int`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isintersection Is this an intersection? May be `ispoint` too! Get method: isintersection(self) - Is this an intersection? May be `ispoint` too! Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ispoint Is this an original point? May be `isintersection` too! Get method: ispoint(self) - Is this an original point? May be `isintersection` too! Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat Get the latitude (`scalar`). Get method: lat(self) - Get the latitude (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon Get the lat- and longitude (LatLon2Tuple). Get method: latlon(self) - Get the lat- and longitude (LatLon2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lon Get the longitude (`scalar`). Get method: lon(self) - Get the longitude (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.